==> v1.0.13.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/room/state/SendStateTask.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.room.state

import org.matrix.android.sdk.api.util.JsonDict
import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.room.RoomAPI
import org.matrix.android.sdk.internal.task.Task
import org.greenrobot.eventbus.EventBus
import javax.inject.Inject

internal interface SendStateTask : Task<SendStateTask.Params, Unit> {
    data class Params(
            val roomId: String,
            val stateKey: String?,
            val eventType: String,
            val body: JsonDict
    )
}

internal class DefaultSendStateTask @Inject constructor(
        private val roomAPI: RoomAPI,
        private val eventBus: EventBus
) : SendStateTask {

    override suspend fun execute(params: SendStateTask.Params) {
        return executeRequest(eventBus) {
            apiCall = if (params.stateKey == null) {
                roomAPI.sendStateEvent(
                        roomId = params.roomId,
                        stateEventType = params.eventType,
                        params = params.body
                )
            } else {
                roomAPI.sendStateEvent(
                        roomId = params.roomId,
                        stateEventType = params.eventType,
                        stateKey = params.stateKey,
                        params = params.body
                )
            }
        }
    }
}

==> v1.1.0.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/room/state/SendStateTask.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.room.state

import org.matrix.android.sdk.api.util.JsonDict
import org.matrix.android.sdk.internal.network.GlobalErrorReceiver
import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.room.RoomAPI
import org.matrix.android.sdk.internal.task.Task
import javax.inject.Inject

internal interface SendStateTask : Task<SendStateTask.Params, Unit> {
    data class Params(
            val roomId: String,
            val stateKey: String?,
            val eventType: String,
            val body: JsonDict
    )
}

internal class DefaultSendStateTask @Inject constructor(
        private val roomAPI: RoomAPI,
        private val globalErrorReceiver: GlobalErrorReceiver
) : SendStateTask {

    override suspend fun execute(params: SendStateTask.Params) {
        return executeRequest(globalErrorReceiver) {
            apiCall = if (params.stateKey == null) {
                roomAPI.sendStateEvent(
                        roomId = params.roomId,
                        stateEventType = params.eventType,
                        params = params.body
                )
            } else {
                roomAPI.sendStateEvent(
                        roomId = params.roomId,
                        stateEventType = params.eventType,
                        stateKey = params.stateKey,
                        params = params.body
                )
            }
        }
    }
}
